" Vim Keymap file for Serbian characters, classical variant, iso-8859-5 encoding
"
" Maintainer:   Aleksandar Veselinovic <aleksa@cs.cmu.edu>
" URL:		    http://www.cs.cmu.edu/~aleksa/personal/vim/keymap/serbian-iso-8859-5.vim
" Last Changed: 2002 Mar 29

scriptencoding iso-8859-5

let b:keymap_name = "serbian-iso-8859-5"

loadkeymap
Q	©
W	ª
E	µ
R	À
T	Â
Y	·
U	Ã
I	¸
O	¾
P	¿
{	È
}	¢
q	ù
w	ú
e	Õ
r	à
t	â
y	×
u	ã
i	Ø
o	Þ
p	ß
[	è
]	ò
A	°
S	Á
D	´
F	Ä
G	³
H	Å
J	¨
K	º
L	»
:	Ç
\"	«
\|	¶
a	Ð
s	á
d	Ô
f	ä
g	Ó
h	å
j	ø
k	Ú
l	Û
;	ç
'	û
\\	Ö
"Z	·
X	¯
C	Æ
V	²
B	±
N	½
M	¼
"z	×
x	ÿ
c	æ
v	Ò
b	Ñ
n	Ý
m	Ü

<	;
>	:
/	-
_	?
,,	?
''	?

" @	"
" #	'
" $	*
" %	:
" ^	,
" &	.
" *	;

