" VIM syntax file
" Language:	groff
" Maintainer:	John Marshall <jmarshall@hey.com>
" Previous Maintainer:	Pedro Alejandro López-Valencia <palopezv@gmail.com>
" Last Change:	2003-05-08-12:41:13 GMT-5.

" This uses the nroff.vim syntax file.
let b:main_syntax = "nroff"
let b:nroff_is_groff = 1
runtime! syntax/nroff.vim
